@@ -52,31 +52,31 @@
 estimate_partition_function <- function(method = "importance_sampling",
                                         alpha_vector, n_items, metric,
                                         nmc, degree, n_iterations, K, cl = NULL,
-                                        seed = NULL){
+                                        seed = NULL) {
 
   stopifnot(degree < length(alpha_vector))
 
-  if(method == "importance_sampling"){
-    if(!is.null(cl)){
+  if (method == "importance_sampling") {
+    if (!is.null(cl)) {
       # Split nmc into each cluster
       nmc_vec <- rep(floor(nmc / length(cl)), length(cl))
       i <- 1
-      while(sum(nmc_vec) != nmc){
+      while (sum(nmc_vec) != nmc) {
         nmc_vec[i] <- nmc_vec[i] + 1
-        if(i > length(cl)) break()
+        if (i > length(cl)) break
       }
       parallel::clusterExport(cl, c("alpha_vector", "n_items", "metric", "seed"),
                               envir = environment())
 
-      estimates <- parallel::parLapply(cl, nmc_vec, function(x){
-        if(!is.null(seed)) set.seed(seed)
+      estimates <- parallel::parLapply(cl, nmc_vec, function(x) {
+        if (!is.null(seed)) set.seed(seed)
         compute_importance_sampling_estimate(alpha_vector = alpha_vector, n_items = n_items,
                                              metric = metric, nmc = x)
       })
 
       log_z <- rowMeans(do.call(cbind, estimates))
     } else {
-      if(!is.null(seed)) set.seed(seed)
+      if (!is.null(seed)) set.seed(seed)
       log_z <- as.numeric(
         compute_importance_sampling_estimate(
           alpha_vector = alpha_vector, n_items = n_items,
@@ -88,7 +88,7 @@ estimate_partition_function <- function(method = "importance_sampling",
       alpha = alpha_vector,
       log_z = log_z
     )
-  } else if(method == "asymptotic"){
+  } else if (method == "asymptotic") {
     stopifnot(metric %in% c("footrule", "spearman"))
 
     estimate <- dplyr::tibble(
