@@ -3,7 +3,7 @@
 
 #include "RcppArmadillo.h"
 #include "misc.h"
-#include "distfuns.h"
+#include "distances.h"
 
 double get_partition_function(int, double, Rcpp::Nullable<arma::vec>,
                               Rcpp::Nullable<arma::vec>, std::string);
