@@ -32,19 +32,19 @@
 //' @export
 // [[Rcpp::export]]
 Rcpp::List smc_mallows_new_item_rank(
-  unsigned int& n_items,
+  const unsigned int& n_items,
   arma::cube& R_obs,
-  std::string& metric,
-  int& leap_size,
-  unsigned int& N,
-  unsigned int Time,
+  const std::string& metric,
+  const int& leap_size,
+  const unsigned int& N,
+  const unsigned int Time,
   const Rcpp::Nullable<arma::vec> logz_estimate,
-  int& mcmc_kernel_app,
-  double alpha_prop_sd,
-  double lambda,
-  double alpha_max,
-  std::string& aug_method,
-  bool verbose = false
+  const int& mcmc_kernel_app,
+  const double alpha_prop_sd,
+  const double lambda,
+  const double alpha_max,
+  const std::string& aug_method,
+  const bool verbose = false
 ) {
   /* ====================================================== */
   /* Initialise Phase                                       */
@@ -53,7 +53,7 @@ Rcpp::List smc_mallows_new_item_rank(
   // Generate N initial samples of rho using the uniform prior
   arma::cube rho_samples(N, n_items, Time, arma::fill::zeros);
   for (arma::uword i = 0; i < N; ++i) {
-    arma::uvec items_sample = arma::randperm(n_items) + 1;
+    const arma::uvec items_sample = arma::randperm(n_items) + 1;
     for (arma::uword j = 0; j < n_items; ++j) {
       rho_samples(i, j, 0) = items_sample(j);
     }
@@ -61,20 +61,20 @@ Rcpp::List smc_mallows_new_item_rank(
 
   /* generate alpha samples using exponential prior ------- */
   arma::mat alpha_samples(N, Time);
-  arma::vec alpha_samples_0 = Rcpp::rexp(N, 1);
+  const arma::vec alpha_samples_0 = Rcpp::rexp(N, 1);
   alpha_samples.col(0) = alpha_samples_0;
 
   /* ====================================================== */
   /* Augment Rankings                                       */
   /* ====================================================== */
-  unsigned int num_ranks = R_obs.n_rows;
+  const unsigned int& num_ranks = R_obs.n_rows;
 
   // each particle has its own set of augmented rankings
   arma::cube aug_rankings(num_ranks, n_items, N, arma::fill::zeros);
   arma::cube prev_aug_rankings(num_ranks, n_items, N, arma::fill::zeros);
 
   // augment incomplete ranks to initialise
-  arma::ivec ranks = Rcpp::seq(1, n_items);
+  const arma::ivec ranks = Rcpp::seq(1, n_items);
 
   // total correction prob
   arma::vec total_correction_prob = Rcpp::rep(1.0, N);
@@ -90,47 +90,37 @@ Rcpp::List smc_mallows_new_item_rank(
       arma::vec R_obs_slice_0_row_jj = R_obs.slice(0).row(jj).t();
       if (aug_method == "random") {
         // find elements missing from original observed ranking
-        arma::vec partial_ranking = R_obs_slice_0_row_jj;
-        Rcpp::NumericVector p_rank_Rcpp, rank_Rcpp;
-        p_rank_Rcpp = partial_ranking;
-        rank_Rcpp = ranks;
-        Rcpp::NumericVector remaining_set = Rcpp::setdiff(rank_Rcpp, p_rank_Rcpp);
+        const Rcpp::NumericVector remaining_set = Rcpp_setdiff_arma(ranks, R_obs_slice_0_row_jj);
 
         // create new agumented ranking by sampling remaining ranks from set uniformly
         arma::vec rset;
-        int remaining_set_length = remaining_set.length();
+        const int& remaining_set_length = remaining_set.length();
         if (remaining_set_length == 1) {
           rset = Rcpp::as<arma::vec>(remaining_set);
         } else {
           rset = Rcpp::as<arma::vec>(Rcpp::sample(remaining_set, remaining_set.length()));
         }
+        arma::vec partial_ranking = R_obs_slice_0_row_jj;
         partial_ranking.elem(arma::find_nonfinite(partial_ranking)) = rset;
 
         aug_rankings.slice(ii).row(jj) = partial_ranking.t();
-        Rcpp::NumericVector remaining_set_length_Rcpp, remaining_set_length_Rcpp_fact;
-        remaining_set_length_Rcpp = remaining_set_length;
-        remaining_set_length_Rcpp_fact = Rcpp::factorial(remaining_set_length_Rcpp);
-        double remaining_set_length_Rcpp_fact_dbl = Rcpp::as<double>(remaining_set_length_Rcpp_fact);
-        total_correction_prob(ii) = total_correction_prob(ii) * (1 / remaining_set_length_Rcpp_fact_dbl);
-      } else if ((aug_method == "pseudolikelihood") & ((metric == "footrule") | (metric == "spearman"))) {
+        total_correction_prob(ii) = divide_by_fact(total_correction_prob(ii), remaining_set_length);
+      } else if ((aug_method == "pseudolikelihood") && ((metric == "footrule") || (metric == "spearman"))) {
         // find items missing from original observed ranking
-        arma::uvec unranked_items = arma::find_nonfinite(R_obs_slice_0_row_jj);
+        const arma::uvec& unranked_items = arma::find_nonfinite(R_obs_slice_0_row_jj);
 
         // find unallocated ranks from original observed ranking
-        Rcpp::NumericVector rank_Rcpp, R_obs_slice_0_row_jj_Rcpp;
-        R_obs_slice_0_row_jj_Rcpp = R_obs_slice_0_row_jj;
-        rank_Rcpp = ranks;
-        Rcpp::NumericVector remaining_set = Rcpp::setdiff(rank_Rcpp, R_obs_slice_0_row_jj_Rcpp);
+        const Rcpp::NumericVector& remaining_set = Rcpp_setdiff_arma(ranks, R_obs_slice_0_row_jj);
 
         // randomly permute the unranked items to give the order in which they will be allocated
         arma::uvec item_ordering;
         item_ordering = arma::conv_to<arma::uvec>::from(arma::shuffle(unranked_items));
-        Rcpp::List proposal = calculate_forward_probability(\
+        const Rcpp::List proposal = calculate_forward_probability(\
           item_ordering, R_obs_slice_0_row_jj, remaining_set, rho_samples.slice(0).row(ii).t(),\
           alpha_samples(ii, 0), n_items, metric\
         );
-        arma::vec a_rank = proposal["aug_ranking"];
-        double f_prob = proposal["forward_prob"];
+        const arma::vec& a_rank = proposal["aug_ranking"];
+        const double& f_prob = proposal["forward_prob"];
         aug_rankings(arma::span(jj), arma::span::all, arma::span(ii)) = a_rank;
         total_correction_prob(ii) *= f_prob;
       } else {
@@ -154,38 +144,32 @@ Rcpp::List smc_mallows_new_item_rank(
     // value of alpha
 
     /* Initializing variables ------------------------------- */
-    const Rcpp::Nullable<arma::vec> cardinalities = R_NilValue;
+    const Rcpp::Nullable<arma::vec>& cardinalities = R_NilValue;
 
     /* Calculating log_z_alpha and log_likelihood ----------- */
-    double log_z_alpha = get_partition_function(\
+    const double& log_z_alpha = get_partition_function(\
       n_items, alpha_samples(ii, 0), cardinalities, logz_estimate, metric\
     );
-    double log_likelihood = get_mallows_loglik(\
+    const double& log_likelihood = get_mallows_loglik(\
       alpha_samples(ii, 0), rho_samples.slice(0).row(ii).t(), n_items,\
       aug_rankings.slice(ii), metric\
     );
-    double log_tcp = std::log(total_correction_prob(ii));
+    const double& log_tcp = std::log(total_correction_prob(ii));
     log_inc_wgt(ii) = log_likelihood - num_ranks * log_z_alpha - log_tcp;
   }
 
     /* normalise weights ------------------------------------ */
-    double maxw = arma::max(log_inc_wgt);
-    arma::vec w = arma::exp(log_inc_wgt - maxw);
-    arma::vec norm_wgt = w / arma::sum(w);
+    const double& maxw = arma::max(log_inc_wgt);
+    const arma::vec& w = arma::exp(log_inc_wgt - maxw);
+    const arma::vec& norm_wgt = w / arma::sum(w);
 
   /* ====================================================== */
   /* Resample                                               */
   /* ====================================================== */
   /* Resample particles using multinomial resampling ------ */
-  // Using norm_wgt_rcpp so that Rcpp::sample compiles. More details on
-  // https://github.com/ocbe-uio/BayesMallows/issues/90#issuecomment-866614296
-  Rcpp::NumericVector norm_wgt_rcpp;
-  norm_wgt_rcpp = norm_wgt;
-  arma::uvec index;
-  index = Rcpp::as<arma::uvec>(Rcpp::sample(N, N, true, norm_wgt_rcpp));
-  index -= 1;
+  arma::uvec index = permutate_with_weights(norm_wgt, N);
   rho_samples.slice(0) = rho_samples.slice(0).rows(index);
-  arma::vec asc = alpha_samples.col(0);
+  const arma::vec& asc = alpha_samples.col(0);
   alpha_samples.col(0) = asc.elem(index);
   aug_rankings = aug_rankings.slices(index);
 
@@ -209,7 +193,7 @@ Rcpp::List smc_mallows_new_item_rank(
           alpha_samples(ii, 0), rho_samples.slice(0).row(ii).t(), n_items,\
           R_obs.slice(0).row(jj).t(), aug_rankings.slice(ii).row(jj).t(), metric\
         );
-      } else if ((aug_method == "pseudolikelihood") & ((metric == "footrule") | (metric == "spearman"))) {
+      } else if ((aug_method == "pseudolikelihood") && ((metric == "footrule") || (metric == "spearman"))) {
         mh_aug_result = metropolis_hastings_aug_ranking_pseudo(\
           alpha_samples(ii, 0), rho_samples.slice(0).row(ii).t(), n_items,\
           R_obs.slice(0).row(jj).t(), aug_rankings.slice(ii).row(jj).t(), metric\
@@ -244,22 +228,22 @@ Rcpp::List smc_mallows_new_item_rank(
       // make the correction
       for (arma::uword jj = 0; jj < num_ranks; ++jj) {
         if (aug_method == "random") {
-          Rcpp::List check_correction = correction_kernel(\
+          const Rcpp::List check_correction = correction_kernel(\
             R_obs.slice(tt + 1).row(jj).t(), aug_rankings.slice(ii).row(jj).t(),\
             n_items
           );
-          arma::vec c_rank = check_correction["ranking"];
-          double c_prob = check_correction["correction_prob"];
+          const arma::vec c_rank = check_correction["ranking"];
+          const double c_prob = check_correction["correction_prob"];
           aug_rankings.slice(ii).row(jj) = c_rank.t();
           particle_correction_prob(ii) *= c_prob;
-        } else if ((aug_method == "pseudolikelihood") & ((metric == "footrule") | (metric == "spearman"))) {
-          Rcpp::List check_correction = correction_kernel_pseudo(\
+        } else if ((aug_method == "pseudolikelihood") && ((metric == "footrule") || (metric == "spearman"))) {
+          const Rcpp::List check_correction = correction_kernel_pseudo(\
             aug_rankings.slice(ii).row(jj).t(), R_obs.slice(tt + 1).row(jj).t(),\
             rho_samples.slice(tt + 1).row(ii).t(), alpha_samples(ii, tt + 1),\
             n_items, metric
           );
-          arma::vec c_rank = check_correction["ranking"];
-          double c_prob = check_correction["correction_prob"];
+          const arma::vec c_rank = check_correction["ranking"];
+          const double c_prob = check_correction["correction_prob"];
           aug_rankings.slice(ii).row(jj) = c_rank.t();
           // # these probs are in real scale
           particle_correction_prob(ii) *= c_prob;
@@ -301,15 +285,9 @@ Rcpp::List smc_mallows_new_item_rank(
     /* Resample                                               */
     /* ====================================================== */
     /* Resample particles using multinomial resampling ------ */
-    // Using norm_wgt_rcpp so that Rcpp::sample compiles. More details on
-    // https://github.com/ocbe-uio/BayesMallows/issues/90#issuecomment-866614296
-    Rcpp::NumericVector norm_wgt_rcpp;
-    norm_wgt_rcpp = norm_wgt;
-    arma::uvec index;
-    index = Rcpp::as<arma::uvec>(Rcpp::sample(N, N, true, norm_wgt_rcpp));
-    index -= 1;
+    arma::uvec index = permutate_with_weights(norm_wgt, N);
     rho_samples.slice(tt + 1) = rho_samples.slice(tt + 1).rows(index);
-    arma::vec asc = alpha_samples.col(tt + 1);
+    const arma::vec& asc = alpha_samples.col(tt + 1);
     alpha_samples.col(tt + 1) = asc.elem(index);
     aug_rankings = aug_rankings.slices(index);
 
@@ -334,7 +312,7 @@ Rcpp::List smc_mallows_new_item_rank(
             n_items, R_obs.slice(tt + 1).row(jj).t(),\
             aug_rankings.slice(ii).row(jj).t(), metric\
           );
-        } else if ((aug_method == "pseudolikelihood") & ((metric == "footrule") | (metric == "spearman"))) {
+        } else if ((aug_method == "pseudolikelihood") && ((metric == "footrule") || (metric == "spearman"))) {
           mh_aug_result = metropolis_hastings_aug_ranking_pseudo(\
             alpha_samples(ii, tt + 1), rho_samples.slice(tt + 1).row(ii).t(),\
             n_items, R_obs.slice(tt + 1).row(jj).t(),\
